@@ -9,7 +9,6 @@ class CreateClassInstanceHandler(AbstractCommandHandler):
 
     def process(self, command):
         try:
-
             if len(command.payload) < self._required_parameters_count:
                 raise Exception("CreateClassInstanceHandler parameters mismatch!")
             clazz = command.payload[0]
@@ -18,7 +17,10 @@ class CreateClassInstanceHandler(AbstractCommandHandler):
                 sig = signature(clazz)
                 if len(sig.parameters) != len(method_arguments):
                     raise Exception("Number of arguments for create class instance are not matching!")
-                return clazz(*method_arguments)
+                try:
+                    return clazz(*method_arguments)
+                except:
+                    raise Exception("Error while creating class instance!")
             return clazz()
         except Exception as e:
             exc_type, exc_value = type(e), e
