@@ -14,7 +14,14 @@ class GetEnumItemHandler(AbstractCommandHandler):
             clazz = command.payload[0]
             enum_name = command.payload[1]
             enum_value = command.payload[2]
-            enum_type = getattr(clazz, enum_name)
+            try:
+                enum_type = getattr(clazz, enum_name)
+            except AttributeError:
+                fields = [field for field in dir(clazz) if not callable(getattr(clazz, field))]
+                message = "Enum {} not found in class {}. Available enums:\n".format(enum_name, clazz.__name__)
+                for field in fields:
+                    message += "{}\n".format(field)
+                raise AttributeError(message)
             return enum_type[enum_value]
         except Exception as e:
             exc_type, exc_value = type(e), e
