@@ -13,7 +13,7 @@ sub throwException {
     my $exception_message =$exception_name . "\n " . $exception_command->{payload}[3];
     my $stack_trace = "";
     if (defined($exception_command->{payload}[4])){
-        $stack_trace = getLocalStackTrace($exception_command->{payload}[4], $exception_command->{payload}[5], $exception_command->{payload}[6], $exception_command->{payload}[7]);
+        $stack_trace = create_stack_trace($exception_command->{payload}[4], $exception_command->{payload}[5], $exception_command->{payload}[6], $exception_command->{payload}[7]);
     }
 
     die $exception_name . " \n " . $exception_message . " \n " .$stack_trace;
