@@ -8,7 +8,7 @@ use Data::Dumper;
 use lib 'lib';
 use lib 'data_seed';
 
-use aliased 'Javonet::Core::Handler::Exception' => 'Exception';
+use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
 sub new {
@@ -34,8 +34,8 @@ sub process {
 
         return 0;
     }
-    catch ( $e ) {
-        return $e;
+    catch ($e){
+        return Exception->new($e);
     }
 }
 
