@@ -27,12 +27,12 @@ sub process {
         }
         my $class_name = $command->{payload}[0];
         my $static_field_name = $command->{payload}[1];
-        my $set_variable_value = $command->{payload}[2];
+        my $new_value = $command->{payload}[2];
 
         no strict 'refs';
-        ${"${class_name}::${static_field_name}"} = $set_variable_value;
+        ${"${class_name}::${static_field_name}"} = $new_value;
 
-        return ${"${class_name}::${static_field_name}"};
+        return 0;
     }
     catch ($e){
         return Exception->new($e);
