@@ -151,7 +151,45 @@ sub get_enum_item {
     );
 }
 
+sub as_out {
+    my $self = shift;
+    my @arguments = @_;
 
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_lib},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('AsOut'),
+        payload => \@arguments
+    );
+
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_lib},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+sub as_ref {
+    my $self = shift;
+    my @arguments = @_;
+
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_lib},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('AsRef'),
+        payload => \@arguments
+    );
+
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_lib},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+#@override
 sub build_command {
     my ($self, $command) = @_;
     my $command_payload_length = @{$command->{payload}};
@@ -164,11 +202,6 @@ sub build_command {
 sub encapsulate_payload_item {
     my ($self, $payload_item) = @_;
     if ($payload_item->isa('Javonet::Sdk::Internal::InvocationContext')) {
-        # return Javonet::Sdk::Core::PerlCommand->new(
-        #     runtime      => $self->{runtime_name},
-        #     command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
-        #     payload      => $payload_item->get_current_command(),
-        # );
         return $payload_item->get_current_command();
     } else {
         return $payload_item;
